==> galois-0.3.1.tar.gz: galois-0.3.1/tests/polys/luts/irreducible_polys_9.py <==
"""
A module containing LUTs for irreducible polynomials over GF(3^2).

Sage:
    def integer(coeffs, order):
        i = 0
        for d, c in enumerate(coeffs[::-1]):
            i += (c.integer_representation() * order**d)
        return i

    order = 3**2
    degree =1
    list_ = []
    R = GF(order, repr="int")["x"]
    for f in R.polynomials(degree):
        if f.is_monic() and f.is_irreducible():
            list_.append(f.coefficients(sparse=False)[::-1])

    # Sort in lexicographically-increasing order
    if not is_prime(order):
        list_ = sorted(list_, key=lambda item: integer(item, order))

    print(f"IRREDUCIBLE_POLYS_{order}_{degree} = {list_}")
"""

# LUT items are poly coefficients in degree-descending order

IRREDUCIBLE_POLYS_9_1 = [
    [1, 0],
    [1, 1],
    [1, 2],
    [1, 3],
    [1, 4],
    [1, 5],
    [1, 6],
    [1, 7],
    [1, 8],
]

IRREDUCIBLE_POLYS_9_2 = [
    [1, 0, 3],
    [1, 0, 5],
    [1, 0, 6],
    [1, 0, 7],
    [1, 1, 3],
    [1, 1, 4],
    [1, 1, 7],
    [1, 1, 8],
    [1, 2, 3],
    [1, 2, 4],
    [1, 2, 7],
    [1, 2, 8],
    [1, 3, 1],
    [1, 3, 2],
    [1, 3, 6],
    [1, 3, 7],
    [1, 4, 4],
    [1, 4, 5],
    [1, 4, 6],
    [1, 4, 8],
    [1, 5, 1],
    [1, 5, 2],
    [1, 5, 3],
    [1, 5, 5],
    [1, 6, 1],
    [1, 6, 2],
    [1, 6, 6],
    [1, 6, 7],
    [1, 7, 1],
    [1, 7, 2],
    [1, 7, 3],
    [1, 7, 5],
    [1, 8, 4],
    [1, 8, 5],
    [1, 8, 6],
    [1, 8, 8],
]

IRREDUCIBLE_POLYS_9_3 = [
    [1, 0, 1, 3],
    [1, 0, 1, 4],
    [1, 0, 1, 5],
    [1, 0, 1, 6],
    [1, 0, 1, 7],
    [1, 0, 1, 8],
    [1, 0, 2, 1],
    [1, 0, 2, 2],
    [1, 0, 2, 3],
    [1, 0, 2, 5],
    [1, 0, 2, 6],
    [1, 0, 2, 7],
    [1, 0, 4, 1],
    [1, 0, 4, 2],
    [1, 0, 4, 3],
    [1, 0, 4, 4],
    [1, 0, 4, 6],
    [1, 0, 4, 8],
    [1, 0, 8, 1],
    [1, 0, 8, 2],
    [1, 0, 8, 4],
    [1, 0, 8, 5],
    [1, 0, 8, 7],
    [1, 0, 8, 8],
    [1, 1, 0, 2],
    [1, 1, 0, 4],
    [1, 1, 0, 8],
    [1, 1, 1, 2],
    [1, 1, 1, 4],
    [1, 1, 1, 8],
    [1, 1, 2, 1],
    [1, 1, 2, 3],
    [1, 1, 2, 7],
    [1, 1, 3, 1],
    [1, 1, 3, 5],
    [1, 1, 3, 8],
    [1, 1, 4, 2],
    [1, 1, 4, 5],
    [1, 1, 4, 7],
    [1, 1, 5, 1],
    [1, 1, 5, 3],
    [1, 1, 5, 7],
    [1, 1, 6, 1],
    [1, 1, 6, 3],
    [1, 1, 6, 7],
    [1, 1, 7, 1],
    [1, 1, 7, 4],
    [1, 1, 7, 6],
    [1, 1, 8, 2],
    [1, 1, 8, 3],
    [1, 1, 8, 6],
    [1, 2, 0, 1],
    [1, 2, 0, 4],
    [1, 2, 0, 8],
    [1, 2, 1, 1],
    [1, 2, 1, 4],
    [1, 2, 1, 8],
    [1, 2, 2, 2],
    [1, 2, 2, 5],
    [1, 2, 2, 6],
    [1, 2, 3, 2],
    [1, 2, 3, 4],
    [1, 2, 3, 7],
    [1, 2, 4, 1],
    [1, 2, 4, 5],
    [1, 2, 4, 7],
    [1, 2, 5, 2],
    [1, 2, 5, 5],
    [1, 2, 5, 6],
    [1, 2, 6, 2],
    [1, 2, 6, 5],
    [1, 2, 6, 6],
    [1, 2, 7, 2],
    [1, 2, 7, 3],
    [1, 2, 7, 8],
    [1, 2, 8, 1],
    [1, 2, 8, 3],
    [1, 2, 8, 6],
    [1, 3, 0, 3],
    [1, 3, 0, 5],
    [1, 3, 0, 6],
    [1, 3, 1, 1],
    [1, 3, 1, 2],
    [1, 3, 1, 5],
    [1, 3, 2, 4],
    [1, 3, 2, 5],
    [1, 3, 2, 8],
    [1, 3, 3, 2],
    [1, 3, 3, 7],
    [1, 3, 3, 8],
    [1, 3, 4, 3],
    [1, 3, 4, 5],
    [1, 3, 4, 6],
    [1, 3, 5, 2],
    [1, 3, 5, 7],
    [1, 3, 5, 8],
    [1, 3, 6, 1],
    [1, 3, 6, 6],
    [1, 3, 6, 7],
    [1, 3, 7, 3],
    [1, 3, 7, 4],
    [1, 3, 7, 7],
    [1, 3, 8, 2],
    [1, 3, 8, 7],
    [1, 3, 8, 8],
    [1, 4, 0, 1],
    [1, 4, 0, 2],
    [1, 4, 0, 4],
    [1, 4, 1, 3],
    [1, 4, 1, 5],
    [1, 4, 1, 8],
    [1, 4, 2, 1],
    [1, 4, 2, 2],
    [1, 4, 2, 4],
    [1, 4, 3, 3],
    [1, 4, 3, 5],
    [1, 4, 3, 8],
    [1, 4, 4, 4],
    [1, 4, 4, 5],
    [1, 4, 4, 7],
    [1, 4, 5, 1],
    [1, 4, 5, 7],
    [1, 4, 5, 8],
    [1, 4, 6, 2],
    [1, 4, 6, 6],
    [1, 4, 6, 8],
    [1, 4, 7, 3],
    [1, 4, 7, 5],
    [1, 4, 7, 8],
    [1, 4, 8, 3],
    [1, 4, 8, 4],
    [1, 4, 8, 6],
    [1, 5, 0, 3],
    [1, 5, 0, 5],
    [1, 5, 0, 7],
    [1, 5, 1, 1],
    [1, 5, 1, 2],
    [1, 5, 1, 3],
    [1, 5, 2, 3],
    [1, 5, 2, 4],
    [1, 5, 2, 8],
    [1, 5, 3, 4],
    [1, 5, 3, 5],
    [1, 5, 3, 6],
    [1, 5, 4, 1],
    [1, 5, 4, 6],
    [1, 5, 4, 8],
    [1, 5, 5, 2],
    [1, 5, 5, 6],
    [1, 5, 5, 7],
    [1, 5, 6, 1],
    [1, 5, 6, 6],
    [1, 5, 6, 8],
    [1, 5, 7, 1],
    [1, 5, 7, 6],
    [1, 5, 7, 8],
    [1, 5, 8, 3],
    [1, 5, 8, 5],
    [1, 5, 8, 7],
    [1, 6, 0, 3],
    [1, 6, 0, 6],
    [1, 6, 0, 7],
    [1, 6, 1, 1],
    [1, 6, 1, 2],
    [1, 6, 1, 7],
    [1, 6, 2, 4],
    [1, 6, 2, 7],
    [1, 6, 2, 8],
    [1, 6, 3, 1],
    [1, 6, 3, 4],
    [1, 6, 3, 5],
    [1, 6, 4, 3],
    [1, 6, 4, 6],
    [1, 6, 4, 7],
    [1, 6, 5, 1],
    [1, 6, 5, 4],
    [1, 6, 5, 5],
    [1, 6, 6, 2],
    [1, 6, 6, 3],
    [1, 6, 6, 5],
    [1, 6, 7, 5],
    [1, 6, 7, 6],
    [1, 6, 7, 8],
    [1, 6, 8, 1],
    [1, 6, 8, 4],
    [1, 6, 8, 5],
    [1, 7, 0, 5],
    [1, 7, 0, 6],
    [1, 7, 0, 7],
    [1, 7, 1, 1],
    [1, 7, 1, 2],
    [1, 7, 1, 6],
    [1, 7, 2, 4],
    [1, 7, 2, 6],
    [1, 7, 2, 8],
    [1, 7, 3, 3],
    [1, 7, 3, 7],
    [1, 7, 3, 8],
    [1, 7, 4, 2],
    [1, 7, 4, 3],
    [1, 7, 4, 4],
    [1, 7, 5, 1],
    [1, 7, 5, 3],
    [1, 7, 5, 5],
    [1, 7, 6, 2],
    [1, 7, 6, 3],
    [1, 7, 6, 4],
    [1, 7, 7, 2],
    [1, 7, 7, 3],
    [1, 7, 7, 4],
    [1, 7, 8, 5],
    [1, 7, 8, 6],
    [1, 7, 8, 7],
    [1, 8, 0, 1],
    [1, 8, 0, 2],
    [1, 8, 0, 8],
    [1, 8, 1, 4],
    [1, 8, 1, 6],
    [1, 8, 1, 7],
    [1, 8, 2, 1],
    [1, 8, 2, 2],
    [1, 8, 2, 8],
    [1, 8, 3, 4],
    [1, 8, 3, 6],
    [1, 8, 3, 7],
    [1, 8, 4, 5],
    [1, 8, 4, 7],
    [1, 8, 4, 8],
    [1, 8, 5, 2],
    [1, 8, 5, 4],
    [1, 8, 5, 5],
    [1, 8, 6, 1],
    [1, 8, 6, 3],
    [1, 8, 6, 4],
    [1, 8, 7, 4],
    [1, 8, 7, 6],
    [1, 8, 7, 7],
    [1, 8, 8, 3],
    [1, 8, 8, 6],
    [1, 8, 8, 8],
]

==> galois-0.3.4.tar.gz: galois-0.3.4/tests/polys/luts/irreducible_polys_9.py <==
"""
A module containing LUTs for irreducible polynomials over GF(3^2).

Sage:
    def integer(coeffs, order):
        i = 0
        for d, c in enumerate(coeffs[::-1]):
            i += (c.integer_representation() * order**d)
        return i

    order = 3**2
    degree =1
    list_ = []
    R = GF(order, repr="int")["x"]
    for f in R.polynomials(degree):
        if f.is_monic() and f.is_irreducible():
            list_.append(f.coefficients(sparse=False)[::-1])

    # Sort in lexicographical order
    if not is_prime(order):
        list_ = sorted(list_, key=lambda item: integer(item, order))

    print(f"IRREDUCIBLE_POLYS_{order}_{degree} = {list_}")
"""

# LUT items are poly coefficients in degree-descending order

IRREDUCIBLE_POLYS_9_1 = [
    [1, 0],
    [1, 1],
    [1, 2],
    [1, 3],
    [1, 4],
    [1, 5],
    [1, 6],
    [1, 7],
    [1, 8],
]

IRREDUCIBLE_POLYS_9_2 = [
    [1, 0, 3],
    [1, 0, 5],
    [1, 0, 6],
    [1, 0, 7],
    [1, 1, 3],
    [1, 1, 4],
    [1, 1, 7],
    [1, 1, 8],
    [1, 2, 3],
    [1, 2, 4],
    [1, 2, 7],
    [1, 2, 8],
    [1, 3, 1],
    [1, 3, 2],
    [1, 3, 6],
    [1, 3, 7],
    [1, 4, 4],
    [1, 4, 5],
    [1, 4, 6],
    [1, 4, 8],
    [1, 5, 1],
    [1, 5, 2],
    [1, 5, 3],
    [1, 5, 5],
    [1, 6, 1],
    [1, 6, 2],
    [1, 6, 6],
    [1, 6, 7],
    [1, 7, 1],
    [1, 7, 2],
    [1, 7, 3],
    [1, 7, 5],
    [1, 8, 4],
    [1, 8, 5],
    [1, 8, 6],
    [1, 8, 8],
]

IRREDUCIBLE_POLYS_9_3 = [
    [1, 0, 1, 3],
    [1, 0, 1, 4],
    [1, 0, 1, 5],
    [1, 0, 1, 6],
    [1, 0, 1, 7],
    [1, 0, 1, 8],
    [1, 0, 2, 1],
    [1, 0, 2, 2],
    [1, 0, 2, 3],
    [1, 0, 2, 5],
    [1, 0, 2, 6],
    [1, 0, 2, 7],
    [1, 0, 4, 1],
    [1, 0, 4, 2],
    [1, 0, 4, 3],
    [1, 0, 4, 4],
    [1, 0, 4, 6],
    [1, 0, 4, 8],
    [1, 0, 8, 1],
    [1, 0, 8, 2],
    [1, 0, 8, 4],
    [1, 0, 8, 5],
    [1, 0, 8, 7],
    [1, 0, 8, 8],
    [1, 1, 0, 2],
    [1, 1, 0, 4],
    [1, 1, 0, 8],
    [1, 1, 1, 2],
    [1, 1, 1, 4],
    [1, 1, 1, 8],
    [1, 1, 2, 1],
    [1, 1, 2, 3],
    [1, 1, 2, 7],
    [1, 1, 3, 1],
    [1, 1, 3, 5],
    [1, 1, 3, 8],
    [1, 1, 4, 2],
    [1, 1, 4, 5],
    [1, 1, 4, 7],
    [1, 1, 5, 1],
    [1, 1, 5, 3],
    [1, 1, 5, 7],
    [1, 1, 6, 1],
    [1, 1, 6, 3],
    [1, 1, 6, 7],
    [1, 1, 7, 1],
    [1, 1, 7, 4],
    [1, 1, 7, 6],
    [1, 1, 8, 2],
    [1, 1, 8, 3],
    [1, 1, 8, 6],
    [1, 2, 0, 1],
    [1, 2, 0, 4],
    [1, 2, 0, 8],
    [1, 2, 1, 1],
    [1, 2, 1, 4],
    [1, 2, 1, 8],
    [1, 2, 2, 2],
    [1, 2, 2, 5],
    [1, 2, 2, 6],
    [1, 2, 3, 2],
    [1, 2, 3, 4],
    [1, 2, 3, 7],
    [1, 2, 4, 1],
    [1, 2, 4, 5],
    [1, 2, 4, 7],
    [1, 2, 5, 2],
    [1, 2, 5, 5],
    [1, 2, 5, 6],
    [1, 2, 6, 2],
    [1, 2, 6, 5],
    [1, 2, 6, 6],
    [1, 2, 7, 2],
    [1, 2, 7, 3],
    [1, 2, 7, 8],
    [1, 2, 8, 1],
    [1, 2, 8, 3],
    [1, 2, 8, 6],
    [1, 3, 0, 3],
    [1, 3, 0, 5],
    [1, 3, 0, 6],
    [1, 3, 1, 1],
    [1, 3, 1, 2],
    [1, 3, 1, 5],
    [1, 3, 2, 4],
    [1, 3, 2, 5],
    [1, 3, 2, 8],
    [1, 3, 3, 2],
    [1, 3, 3, 7],
    [1, 3, 3, 8],
    [1, 3, 4, 3],
    [1, 3, 4, 5],
    [1, 3, 4, 6],
    [1, 3, 5, 2],
    [1, 3, 5, 7],
    [1, 3, 5, 8],
    [1, 3, 6, 1],
    [1, 3, 6, 6],
    [1, 3, 6, 7],
    [1, 3, 7, 3],
    [1, 3, 7, 4],
    [1, 3, 7, 7],
    [1, 3, 8, 2],
    [1, 3, 8, 7],
    [1, 3, 8, 8],
    [1, 4, 0, 1],
    [1, 4, 0, 2],
    [1, 4, 0, 4],
    [1, 4, 1, 3],
    [1, 4, 1, 5],
    [1, 4, 1, 8],
    [1, 4, 2, 1],
    [1, 4, 2, 2],
    [1, 4, 2, 4],
    [1, 4, 3, 3],
    [1, 4, 3, 5],
    [1, 4, 3, 8],
    [1, 4, 4, 4],
    [1, 4, 4, 5],
    [1, 4, 4, 7],
    [1, 4, 5, 1],
    [1, 4, 5, 7],
    [1, 4, 5, 8],
    [1, 4, 6, 2],
    [1, 4, 6, 6],
    [1, 4, 6, 8],
    [1, 4, 7, 3],
    [1, 4, 7, 5],
    [1, 4, 7, 8],
    [1, 4, 8, 3],
    [1, 4, 8, 4],
    [1, 4, 8, 6],
    [1, 5, 0, 3],
    [1, 5, 0, 5],
    [1, 5, 0, 7],
    [1, 5, 1, 1],
    [1, 5, 1, 2],
    [1, 5, 1, 3],
    [1, 5, 2, 3],
    [1, 5, 2, 4],
    [1, 5, 2, 8],
    [1, 5, 3, 4],
    [1, 5, 3, 5],
    [1, 5, 3, 6],
    [1, 5, 4, 1],
    [1, 5, 4, 6],
    [1, 5, 4, 8],
    [1, 5, 5, 2],
    [1, 5, 5, 6],
    [1, 5, 5, 7],
    [1, 5, 6, 1],
    [1, 5, 6, 6],
    [1, 5, 6, 8],
    [1, 5, 7, 1],
    [1, 5, 7, 6],
    [1, 5, 7, 8],
    [1, 5, 8, 3],
    [1, 5, 8, 5],
    [1, 5, 8, 7],
    [1, 6, 0, 3],
    [1, 6, 0, 6],
    [1, 6, 0, 7],
    [1, 6, 1, 1],
    [1, 6, 1, 2],
    [1, 6, 1, 7],
    [1, 6, 2, 4],
    [1, 6, 2, 7],
    [1, 6, 2, 8],
    [1, 6, 3, 1],
    [1, 6, 3, 4],
    [1, 6, 3, 5],
    [1, 6, 4, 3],
    [1, 6, 4, 6],
    [1, 6, 4, 7],
    [1, 6, 5, 1],
    [1, 6, 5, 4],
    [1, 6, 5, 5],
    [1, 6, 6, 2],
    [1, 6, 6, 3],
    [1, 6, 6, 5],
    [1, 6, 7, 5],
    [1, 6, 7, 6],
    [1, 6, 7, 8],
    [1, 6, 8, 1],
    [1, 6, 8, 4],
    [1, 6, 8, 5],
    [1, 7, 0, 5],
    [1, 7, 0, 6],
    [1, 7, 0, 7],
    [1, 7, 1, 1],
    [1, 7, 1, 2],
    [1, 7, 1, 6],
    [1, 7, 2, 4],
    [1, 7, 2, 6],
    [1, 7, 2, 8],
    [1, 7, 3, 3],
    [1, 7, 3, 7],
    [1, 7, 3, 8],
    [1, 7, 4, 2],
    [1, 7, 4, 3],
    [1, 7, 4, 4],
    [1, 7, 5, 1],
    [1, 7, 5, 3],
    [1, 7, 5, 5],
    [1, 7, 6, 2],
    [1, 7, 6, 3],
    [1, 7, 6, 4],
    [1, 7, 7, 2],
    [1, 7, 7, 3],
    [1, 7, 7, 4],
    [1, 7, 8, 5],
    [1, 7, 8, 6],
    [1, 7, 8, 7],
    [1, 8, 0, 1],
    [1, 8, 0, 2],
    [1, 8, 0, 8],
    [1, 8, 1, 4],
    [1, 8, 1, 6],
    [1, 8, 1, 7],
    [1, 8, 2, 1],
    [1, 8, 2, 2],
    [1, 8, 2, 8],
    [1, 8, 3, 4],
    [1, 8, 3, 6],
    [1, 8, 3, 7],
    [1, 8, 4, 5],
    [1, 8, 4, 7],
    [1, 8, 4, 8],
    [1, 8, 5, 2],
    [1, 8, 5, 4],
    [1, 8, 5, 5],
    [1, 8, 6, 1],
    [1, 8, 6, 3],
    [1, 8, 6, 4],
    [1, 8, 7, 4],
    [1, 8, 7, 6],
    [1, 8, 7, 7],
    [1, 8, 8, 3],
    [1, 8, 8, 6],
    [1, 8, 8, 8],
]
